export default defineEventHandler(async (event) => {
  const _session = await requireUserSession(event)
  const response = await call_create_hls_channel_api()
  return { channel_id: response.channel_id, sora_url: response.sora_url }
})

type CreateChannelResponse = {
  channel_id: string
  sora_url: string
}

// チャンネル作成
async function call_create_hls_channel_api(): Promise<CreateChannelResponse> {
  const response = await $fetch(process.env.IMAGEFLUX_API_ENDPOINT as string, {
    method: 'POST',
    headers: {
      'Authorization': 'Bearer ' + process.env.IMAGEFLUX_ACCESS_TOKEN,
      'X-Sora-Target': 'ImageFlux_20200316.CreateMultistreamChannelWithHLS',
    },
    body: {
      hls: [
        {
          durationSeconds: 2,
          startTimeOffset: -2,
          video: {
            width: 720 * 2,
            height: 480 * 2,
            fps: 30,
            bps: 1000000,
          },
          audio: {
            bps: 96000,
          },
        },
      ],
      auth_webhook_url: process.env.IMAGEFLUX_AUTH_WEBHOOK,
      event_webhook_url: process.env.IMAGEFLUX_EVENT_WEBHOOK,
      encrypt_key_uri: process.env.IMAGEFLUX_ENCRYPT_KEY,
    },
  })
  return response as CreateChannelResponse
}

async function _call_create_channel_api(): Promise<CreateChannelResponse> {
  const response = await $fetch(process.env.IMAGEFLUX_API_ENDPOINT as string, {
    method: 'POST',
    headers: {
      'Authorization': 'Bearer ' + process.env.IMAGEFLUX_ACCESS_TOKEN,
      'X-Sora-Target': 'ImageFlux_20200316.CreateMultistreamChannel',
    },
    body: {
      auth_webhook_url: process.env.IMAGEFLUX_AUTH_WEBHOOK,
      event_webhook_url: process.env.IMAGEFLUX_EVENT_WEBHOOK,
    },
  })
  return response as CreateChannelResponse
}
