export default defineEventHandler(async (event) => {
  const _session = await requireUserSession(event)
  const query = getQuery(event)
  const response = await call_encrypt_key_api(query.kid as string)
  const encrypt_key_hex = response.encrypt_key
  const encrypt_key_bin = Buffer.from(encrypt_key_hex, 'hex')
  setHeader(event, 'Content-Length', encrypt_key_bin.length)
  setHeader(event, 'Content-Type', 'application/octet-stream')
  return encrypt_key_bin
})

type GetEncryptKeyResponse = {
  encrypt_key: string
}

// 暗号鍵取得
async function call_encrypt_key_api(kid: string): Promise<GetEncryptKeyResponse> {
  const response = await $fetch(process.env.IMAGEFLUX_API_ENDPOINT as string, {
    method: 'POST',
    headers: {
      'Authorization': 'Bearer ' + process.env.IMAGEFLUX_ACCESS_TOKEN,
      'X-Sora-Target': 'ImageFlux_20200707.GetEncryptKey',
    },
    body: {
      kid,
    },
  })
  return response as GetEncryptKeyResponse
}
