export default defineEventHandler(async (event) => {
  const _session = await requireUserSession(event)
  const request = await readBody(event)
  try {
    const response = await call_list_playlist_urls_api(request.channel_id)
    return response
  }
  catch (e) {
    console.error(e)
    throw createError({
      statusCode: 401,
      message: (e instanceof Error) ? e.message : e + '',
    })
  }
  return {}
})

type HLS = {
  connection_id: string
  playlist_url: string
}

type ListPlaylistURLsResponse = {
  channel_id: string
  hls: HLS[]
}

// チャンネル削除
async function call_list_playlist_urls_api(channel_id: string): Promise<ListPlaylistURLsResponse> {
  const response = await $fetch(process.env.IMAGEFLUX_API_ENDPOINT as string, {
    method: 'POST',
    headers: {
      'Authorization': 'Bearer ' + process.env.IMAGEFLUX_ACCESS_TOKEN,
      'X-Sora-Target': 'ImageFlux_20200207.ListPlaylistURLs',
    },
    body: {
      channel_id,
    },
  })
  return response as ListPlaylistURLsResponse
}
